<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS language="uk" version="2.1">
<context>
    <name>AboutDlg</name>
    <message>
        <source>About</source>
        <translation>Про програму</translation>
    </message>
</context>
<context>
    <name>AddNewTorrentDialog</name>
    <message>
        <source>Category:</source>
        <translation>Категорія:</translation>
    </message>
    <message>
        <source>Start torrent</source>
        <translation>Запустити торрент</translation>
    </message>
    <message>
        <source>Skip hash check</source>
        <translation>Пропустити перевірку хешу</translation>
    </message>
    <message>
        <source>Create subfolder</source>
        <translation>Створити підтеку</translation>
    </message>
    <message>
        <source>Torrent Management Mode:</source>
        <translation>Режим керування торентом:</translation>
    </message>
</context>
<context>
    <name>CategoryFilterModel</name>
    <message>
        <source>All</source>
        <translation>Всі</translation>
    </message>
    <message>
        <source>Uncategorized</source>
        <translation>Без категорії</translation>
    </message>
</context>
<context>
    <name>CategoryFilterWidget</name>
    <message>
        <source>Add category...</source>
        <translation>Додати категорію...</translation>
    </message>
    <message>
        <source>Remove category</source>
        <translation>Видалити категорію</translation>
    </message>
    <message>
        <source>Remove unused categories</source>
        <translation>Вилучити невикористовувані категорії</translation>
    </message>
    <message>
        <source>Resume torrents</source>
        <translation>Продовжити торренти</translation>
    </message>
    <message>
        <source>Pause torrents</source>
        <translation>Призупинити торренти</translation>
    </message>
    <message>
        <source>Delete torrents</source>
        <translation>Видалити торренти</translation>
    </message>
    <message>
        <source>New Category</source>
        <translation>Нова категорія</translation>
    </message>
    <message>
        <source>Edit category...</source>
        <translation>Змінити категорію...</translation>
    </message>
</context>
<context>
    <name>HttpServer</name>
    <message>
        <source>Exit qBittorrent</source>
        <translation>Вийти з qBittorrent</translation>
    </message>
    <message>
        <source>Only one link per line</source>
        <translation>Одне посилання на рядок</translation>
    </message>
    <message>
        <source>Global upload rate limit must be greater than 0 or disabled.</source>
        <translation>Глобальний ліміт швидкості вивантаження повинен бути більшим 0 або відсутнім.</translation>
    </message>
    <message>
        <source>Global download rate limit must be greater than 0 or disabled.</source>
        <translation>Глобальний ліміт швидкості завантаження повинен бути більшим 0 або відсутнім.</translation>
    </message>
    <message>
        <source>Alternative upload rate limit must be greater than 0 or disabled.</source>
        <translation>Альтернативний ліміт швидкості вивантаження повинен бути більшим 0 або відсутнім.</translation>
    </message>
    <message>
        <source>Alternative download rate limit must be greater than 0 or disabled.</source>
        <translation>Альтернативний ліміт швидкості завантаження повинен бути більшим 0 або відсутнім.</translation>
    </message>
    <message>
        <source>Maximum active downloads must be greater than -1.</source>
        <translation>Максимальна кількість активних завантажень повинна бути більша за -1.</translation>
    </message>
    <message>
        <source>Maximum active uploads must be greater than -1.</source>
        <translation>Максимальна кількість активних вивантажень повинна бути більша за -1.</translation>
    </message>
    <message>
        <source>Maximum active torrents must be greater than -1.</source>
        <translation>Максимальна кількість активних торрентів повинна бути більша за -1.</translation>
    </message>
    <message>
        <source>Maximum number of connections limit must be greater than 0 or disabled.</source>
        <translation>Максимальна кількість з'єднань повинна бути більша 0 або відсутня.</translation>
    </message>
    <message>
        <source>Maximum number of connections per torrent limit must be greater than 0 or disabled.</source>
        <translation>Максимальна кількість з'єднань на торрент повинна бути більша 0 або відсутня.</translation>
    </message>
    <message>
        <source>Maximum number of upload slots per torrent limit must be greater than 0 or disabled.</source>
        <translation>Максимальна кількість з'єднань для вивантаження на торрент повинна бути більша 0 або відсутня.</translation>
    </message>
    <message>
        <source>Unable to save program preferences, qBittorrent is probably unreachable.</source>
        <translation>Не вдалося зберегти налаштування програми, можливо qBittorrent недоступний.</translation>
    </message>
    <message>
        <source>IRC: #qbittorrent on Freenode</source>
        <translation>IRC: #qbittorrent на Freenode</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Невідомо</translation>
    </message>
    <message>
        <source>Share ratio limit must be between 0 and 9998.</source>
        <translation>Коефіцієнт роздачі має бути у діапазоні від 0 до 9998.</translation>
    </message>
    <message>
        <source>Seeding time limit must be between 0 and 525600 minutes.</source>
        <translation>Обмеження часу роздачі має бути у діапазоні від 0 до 525600 хвилин.</translation>
    </message>
    <message>
        <source>The port used for incoming connections must be between 1 and 65535.</source>
        <translation>Порт, який використовується для вхідних підключень, повинен бути між 1 і 65535.</translation>
    </message>
    <message>
        <source>The port used for the Web UI must be between 1 and 65535.</source>
        <translation>Порт, який використовується для Веб-інтерфейсу повинен бути між 1 і 65535.</translation>
    </message>
    <message>
        <source>Unable to log in, qBittorrent is probably unreachable.</source>
        <translation>Не вдалось залогуватись, qBittorrent напевне недосяжний</translation>
    </message>
    <message>
        <source>Invalid Username or Password.</source>
        <translation>Неправильний логін або пароль.</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Ім'я користувача</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Пароль</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Логін</translation>
    </message>
    <message>
        <source>Original authors</source>
        <translation>Оригінальні автори</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Застосувати</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Додати</translation>
    </message>
    <message>
        <source>Upload Torrents</source>
        <comment>Upload torrent files to qBittorent using WebUI</comment>
        <translation>Вивантажити торренти</translation>
    </message>
    <message>
        <source>Save files to location:</source>
        <translation>Зберігати файли до:</translation>
    </message>
    <message>
        <source>Cookie:</source>
        <translation>Кукі:</translation>
    </message>
    <message>
        <source>Type folder here</source>
        <translation>Введіть тут назву теки</translation>
    </message>
    <message>
        <source>More information</source>
        <translation>Детальніше</translation>
    </message>
    <message>
        <source>Information about certificates</source>
        <translation>Інформація про сертифікати</translation>
    </message>
    <message>
        <source>Set location</source>
        <translation>Задати розташування</translation>
    </message>
    <message>
        <source>Limit upload rate</source>
        <translation>Обмеження швидкості відвантаження</translation>
    </message>
    <message>
        <source>Limit download rate</source>
        <translation>Обмеження швидкості завантаження</translation>
    </message>
    <message>
        <source>Rename torrent</source>
        <translation>Перейменувати торрент</translation>
    </message>
    <message>
        <source>Other...</source>
        <comment>Save Files to: Watch Folder / Default Folder / Other...</comment>
        <translation>Інша...</translation>
    </message>
    <message>
        <source>Monday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Понеділок</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Вівторок</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Середа</translation>
    </message>
    <message>
        <source>Thursday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Четвер</translation>
    </message>
    <message>
        <source>Friday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>П'ятниця</translation>
    </message>
    <message>
        <source>Saturday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Субота</translation>
    </message>
    <message>
        <source>Sunday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Неділя</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Вийти</translation>
    </message>
    <message>
        <source>Download Torrents from their URLs or Magnet links</source>
        <translation>Завантажити торренти з їх URL або magnet-посилань</translation>
    </message>
    <message>
        <source>Upload local torrent</source>
        <translation>Вивантажити локальний торрент</translation>
    </message>
    <message>
        <source>Are you sure you want to delete the selected torrents from the transfer list?</source>
        <translation>Ви впевнені, що хочете видалити вибрані торренти зі списку завантажень?</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Зберегти</translation>
    </message>
    <message>
        <source>qBittorrent client is not reachable</source>
        <translation>Клієнт qBittorrent недосяжний</translation>
    </message>
    <message>
        <source>Global number of upload slots limit must be greater than 0 or disabled.</source>
        <translation>Глобальне число обмежень на місця завантаження повинно бути більше 0 або вимкнено.</translation>
    </message>
    <message>
        <source>Invalid category name:\nPlease do not use any special characters in the category name.</source>
        <translation>Некоректна назва категорії:\nБудь ласка, не використовуйте спеціальні символи у назві категорії.</translation>
    </message>
    <message>
        <source>Unable to create category</source>
        <translation>Не вдалося створити категорію</translation>
    </message>
    <message>
        <source>Upload rate threshold must be greater than 0.</source>
        <translation>Поріг швидкості завантаження повинен бути більше 0.</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Редагувати</translation>
    </message>
    <message>
        <source>Free space: %1</source>
        <translation>Вільного місця: %1</translation>
    </message>
    <message>
        <source>Torrent inactivity timer must be greater than 0.</source>
        <translation>Таймер бездіяльності торрента повинен бути більше 0.</translation>
    </message>
    <message>
        <source>Saving Management</source>
        <translation>Керування зберіганням</translation>
    </message>
    <message>
        <source>Download rate threshold must be greater than 0.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>qBittorrent has been shutdown</source>
        <translation>qBittorrent вимкнено.</translation>
    </message>
    <message>
        <source>JavaScript Required! You must enable JavaScript for the Web UI to work properly</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Edit</source>
        <translation>Торренти</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Інструменти</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Файл</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Допомога</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Показати</translation>
    </message>
    <message>
        <source>Options...</source>
        <translation>Налаштування...</translation>
    </message>
    <message>
        <source>Resume</source>
        <translation>Продовжити</translation>
    </message>
    <message>
        <source>Minimum Priority</source>
        <translation>Найнижчий пріоритет</translation>
    </message>
    <message>
        <source>Top Priority</source>
        <translation>Найвищий пріоритет</translation>
    </message>
    <message>
        <source>Decrease Priority</source>
        <translation>Зменшити пріоритет</translation>
    </message>
    <message>
        <source>Increase Priority</source>
        <translation>Збільшити пріоритет</translation>
    </message>
    <message>
        <source>Top Toolbar</source>
        <translation>Верхню панель</translation>
    </message>
    <message>
        <source>Status Bar</source>
        <translation>Рядок стану</translation>
    </message>
    <message>
        <source>Speed in Title Bar</source>
        <translation>Швидкість у заголовку</translation>
    </message>
    <message>
        <source>Donate!</source>
        <translation>Пожертвувати гроші</translation>
    </message>
    <message>
        <source>Resume All</source>
        <translation>Продовжити всі</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>Статистика</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Про програму</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Призупинити</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Видалити</translation>
    </message>
    <message>
        <source>Pause All</source>
        <translation>Зупинити всі</translation>
    </message>
    <message>
        <source>Add Torrent File...</source>
        <translation>Додати torrent-файл...</translation>
    </message>
    <message>
        <source>Documentation</source>
        <translation>Документація</translation>
    </message>
    <message>
        <source>Add Torrent Link...</source>
        <translation>Додати посилання на торрент</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Так</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Ні</translation>
    </message>
    <message>
        <source>Global Upload Speed Limit</source>
        <translation>Глобальний ліміт вивантаження</translation>
    </message>
    <message>
        <source>Global Download Speed Limit</source>
        <translation>Глобальний ліміт завантаження</translation>
    </message>
    <message>
        <source>Are you sure you want to quit qBittorrent?</source>
        <translation>Ви впевнені, що хочете вийти з qBittorrent?</translation>
    </message>
    <message>
        <source>[D: %1, U: %2] qBittorrent %3</source>
        <comment>D = Download; U = Upload; %3 is qBittorrent version</comment>
        <translation>[З: %1, В: %2] qBittorrent %3</translation>
    </message>
    <message>
        <source>Alternative speed limits</source>
        <translation>Альтернативні обмеження швидкості</translation>
    </message>
    <message>
        <source>Search Engine</source>
        <translation>Пошуковик</translation>
    </message>
    <message>
        <source>Filter torrent list...</source>
        <translation>Фільтрувати список торрентів...</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Пошук</translation>
    </message>
    <message>
        <source>Transfers</source>
        <translation>Завантаження</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Налаштування</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Завантаження</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>З'єднання</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Швидкість</translation>
    </message>
    <message>
        <source>BitTorrent</source>
        <translation>BitTorrent</translation>
    </message>
    <message>
        <source>Web UI</source>
        <translation>Веб-інтерфейс</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Мова</translation>
    </message>
    <message>
        <source>User Interface Language:</source>
        <translation>Мова інтерфейсу:</translation>
    </message>
    <message>
        <source>Email notification upon download completion</source>
        <translation>Сповіщення через e-mail про завершення завантажень</translation>
    </message>
    <message>
        <source>Run external program on torrent completion</source>
        <translation>Запустити зовнішню програму при завершенні торрента</translation>
    </message>
    <message>
        <source>IP Filtering</source>
        <translation>Фільтрування IP</translation>
    </message>
    <message>
        <source>Schedule the use of alternative rate limits</source>
        <translation>Використання альтернативних обмежень швидкості за розкладом</translation>
    </message>
    <message>
        <source>Torrent Queueing</source>
        <translation>Черга торрентів</translation>
    </message>
    <message>
        <source>Seed torrents until their seeding time reaches</source>
        <translation>Сідувати торренти, доки час їх роздачі не досягне</translation>
    </message>
    <message>
        <source>Automatically add these trackers to new downloads:</source>
        <translation>Автоматично додавати ці трекери до нових завантажень:</translation>
    </message>
    <message>
        <source>Web User Interface (Remote control)</source>
        <translation>Веб-інтерфейс користувача (дистанційне керування)</translation>
    </message>
    <message>
        <source>IP address:</source>
        <translation>IP адреса:</translation>
    </message>
    <message>
        <source>Server domains:</source>
        <translation>Домени сервера:</translation>
    </message>
    <message>
        <source>Use HTTPS instead of HTTP</source>
        <translation>Використовувати HTTPS замість HTTP</translation>
    </message>
    <message>
        <source>Bypass authentication for clients on localhost</source>
        <translation>Пропустити автентифікацію для клієнтів на цьому ж комп'ютері</translation>
    </message>
    <message>
        <source>Bypass authentication for clients in whitelisted IP subnets</source>
        <translation>Пропустити автентифікацію для клієнтів із дозволених підмереж IP</translation>
    </message>
    <message>
        <source>Update my dynamic domain name</source>
        <translation>Оновлювати мій динамічний домен</translation>
    </message>
    <message>
        <source>Keep incomplete torrents in:</source>
        <translation>Тримати незавершені торренти у:</translation>
    </message>
    <message>
        <source>Copy .torrent files to:</source>
        <translation>Копіювати torrent-файли до:</translation>
    </message>
    <message>
        <source>Copy .torrent files for finished downloads to:</source>
        <translation>Копіювати torrent-файли для завершених завантажень до:</translation>
    </message>
    <message>
        <source>Pre-allocate disk space for all files</source>
        <translation>Попередньо виділяти місце для всіх файлів</translation>
    </message>
    <message>
        <source>Append .!qB extension to incomplete files</source>
        <translation>Додавати розширення .!qB до незавершених файлів</translation>
    </message>
    <message>
        <source>Automatically add torrents from:</source>
        <translation>Автоматично додавати торренти із:</translation>
    </message>
    <message>
        <source>SMTP server:</source>
        <translation>Сервер SMTP:</translation>
    </message>
    <message>
        <source>This server requires a secure connection (SSL)</source>
        <translation>Цей сервер вимагає безпечного з'єднання (SSL)</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>Автентифікація</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Ім'я користувача:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Пароль:</translation>
    </message>
    <message>
        <source>Enabled protocol:</source>
        <translation>Задіяні протоколи:</translation>
    </message>
    <message>
        <source>TCP and μTP</source>
        <translation>TCP та μTP</translation>
    </message>
    <message>
        <source>Listening Port</source>
        <translation>Порт для вхідних з'єднань</translation>
    </message>
    <message>
        <source>Port used for incoming connections:</source>
        <translation>Порт, який використовуватиметься для вхідних з'єднань:</translation>
    </message>
    <message>
        <source>Use UPnP / NAT-PMP port forwarding from my router</source>
        <translation>Використовувати UPnP / NAT-PMP з мого роутера</translation>
    </message>
    <message>
        <source>Use different port on each startup</source>
        <translation>Використовувати щоразу інший порт</translation>
    </message>
    <message>
        <source>Connections Limits</source>
        <translation>Обмеження з'єднань</translation>
    </message>
    <message>
        <source>Maximum number of connections per torrent:</source>
        <translation>Максимальна кількість з'єднань на торрент:</translation>
    </message>
    <message>
        <source>Global maximum number of connections:</source>
        <translation>Максимальна кількість з'єднань:</translation>
    </message>
    <message>
        <source>Maximum number of upload slots per torrent:</source>
        <translation>Макс. з'єднань для вивантаження на торрент:</translation>
    </message>
    <message>
        <source>Global maximum number of upload slots:</source>
        <translation>Максимальна кількість з'єднань для вивантаження:</translation>
    </message>
    <message>
        <source>Proxy Server</source>
        <translation>Проксі-сервер</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Тип:</translation>
    </message>
    <message>
        <source>(None)</source>
        <translation>(Немає)</translation>
    </message>
    <message>
        <source>SOCKS4</source>
        <translation>SOCKS4</translation>
    </message>
    <message>
        <source>SOCKS5</source>
        <translation>SOCKS5</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>Адреса:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Порт:</translation>
    </message>
    <message>
        <source>Use proxy for peer connections</source>
        <translation>Використовувати проксі для з'єднання з пірами</translation>
    </message>
    <message>
        <source>Disable connections not supported by proxies</source>
        <translation>Вимкнути з'єднання, які не підтримуються проксі-серверами.</translation>
    </message>
    <message>
        <source>Use proxy only for torrents</source>
        <translation>Використовувати проксі лише для торрентів</translation>
    </message>
    <message>
        <source>Filter path (.dat, .p2p, .p2b):</source>
        <translation>Шлях до фільтра (.dat, .p2p, .p2b):</translation>
    </message>
    <message>
        <source>Manually banned IP addresses...</source>
        <translation>Вручну заблоковані IP-адреси...</translation>
    </message>
    <message>
        <source>Apply to trackers</source>
        <translation>Застосувати до трекерів</translation>
    </message>
    <message>
        <source>Global Rate Limits</source>
        <translation>Глобальні обмеження швидкості</translation>
    </message>
    <message>
        <source>Upload:</source>
        <translation>Вивантаження:</translation>
    </message>
    <message>
        <source>Download:</source>
        <translation>Завантаження:</translation>
    </message>
    <message>
        <source>Alternative Rate Limits</source>
        <translation>Альтернативні обмеження швидкості</translation>
    </message>
    <message>
        <source>From:</source>
        <extracomment>from (time1 to time2)</extracomment>
        <translation>З:</translation>
    </message>
    <message>
        <source>To:</source>
        <extracomment>time1 to time2</extracomment>
        <translation>До:</translation>
    </message>
    <message>
        <source>When:</source>
        <translation>Коли:</translation>
    </message>
    <message>
        <source>Every day</source>
        <translation>Щодня</translation>
    </message>
    <message>
        <source>Weekdays</source>
        <translation>Робочі дні</translation>
    </message>
    <message>
        <source>Weekends</source>
        <translation>Вихідні</translation>
    </message>
    <message>
        <source>Rate Limits Settings</source>
        <translation>Налаштування обмежень швидкості</translation>
    </message>
    <message>
        <source>Apply rate limit to transport overhead</source>
        <translation>Включати в обмеження протокол передачі</translation>
    </message>
    <message>
        <source>Apply rate limit to µTP protocol</source>
        <translation>Включати в обмеження протокол uTP</translation>
    </message>
    <message>
        <source>Privacy</source>
        <translation>Конфіденційність</translation>
    </message>
    <message>
        <source>Enable DHT (decentralized network) to find more peers</source>
        <translation>Увімкнути DHT (децентралізовану мережу), щоб знаходити більше пірів</translation>
    </message>
    <message>
        <source>Enable Peer Exchange (PeX) to find more peers</source>
        <translation>Увімкнути обмін пірами (PeX), щоб знаходити більше пірів</translation>
    </message>
    <message>
        <source>Enable Local Peer Discovery to find more peers</source>
        <translation>Увімкнути локальний пошук пірів, щоб знаходити більше пірів</translation>
    </message>
    <message>
        <source>Encryption mode:</source>
        <translation>Режим шифрування:</translation>
    </message>
    <message>
        <source>Prefer encryption</source>
        <translation>Надавати перевагу шифруванню</translation>
    </message>
    <message>
        <source>Require encryption</source>
        <translation>Вимагати шифрування</translation>
    </message>
    <message>
        <source>Disable encryption</source>
        <translation>Вимкнути шифрування</translation>
    </message>
    <message>
        <source>Enable anonymous mode</source>
        <translation>Увімкнути анонімний режим</translation>
    </message>
    <message>
        <source>Maximum active downloads:</source>
        <translation>Макс. активних завантажень:</translation>
    </message>
    <message>
        <source>Maximum active uploads:</source>
        <translation>Макс. активних вивантажень:</translation>
    </message>
    <message>
        <source>Maximum active torrents:</source>
        <translation>Макс. активних торрентів:</translation>
    </message>
    <message>
        <source>Do not count slow torrents in these limits</source>
        <translation>Не враховувати повільні торренти до цих обмежень</translation>
    </message>
    <message>
        <source>Share Ratio Limiting</source>
        <translation>Обмеження вивантаження</translation>
    </message>
    <message>
        <source>Seed torrents until their ratio reaches</source>
        <translation>Сідувати торренти, доки їх коефіцієнт не досягне</translation>
    </message>
    <message>
        <source>then</source>
        <translation>а тоді</translation>
    </message>
    <message>
        <source>Pause them</source>
        <translation>Призупинити їх</translation>
    </message>
    <message>
        <source>Remove them</source>
        <translation>Видалити їх</translation>
    </message>
    <message>
        <source>Use UPnP / NAT-PMP to forward the port from my router</source>
        <translation>Використовувати UPnP / NAT-PMP, щоб направити порт в роутері</translation>
    </message>
    <message>
        <source>Certificate:</source>
        <translation>Сертифікат:</translation>
    </message>
    <message>
        <source>Key:</source>
        <translation>Ключ:</translation>
    </message>
    <message>
        <source>Register</source>
        <translation>Зареєструватись</translation>
    </message>
    <message>
        <source>Domain name:</source>
        <translation>Домен:</translation>
    </message>
    <message>
        <source>Supported parameters (case sensitive):</source>
        <translation>Підтримувані параметри (чутливо до регістру):</translation>
    </message>
    <message>
        <source>%N: Torrent name</source>
        <translation>%N: Назва торрента</translation>
    </message>
    <message>
        <source>%L: Category</source>
        <translation>%L: Категорія</translation>
    </message>
    <message>
        <source>%G: Tags (seperated by comma)</source>
        <translation>%G: Мітки (розділені комами)</translation>
    </message>
    <message>
        <source>%F: Content path (same as root path for multifile torrent)</source>
        <translation>%F: Шлях вмісту (для торрента з багатьма файлами те саме що корінь)</translation>
    </message>
    <message>
        <source>%R: Root path (first torrent subdirectory path)</source>
        <translation>%R: Кореневий шлях (шлях до головної теки торрента)</translation>
    </message>
    <message>
        <source>%D: Save path</source>
        <translation>%D: Шлях збереження</translation>
    </message>
    <message>
        <source>%C: Number of files</source>
        <translation>%C: Кількість файлів</translation>
    </message>
    <message>
        <source>%Z: Torrent size (bytes)</source>
        <translation>%Z: Розмір торрента (в байтах)</translation>
    </message>
    <message>
        <source>%T: Current tracker</source>
        <translation>%T: Поточний трекер</translation>
    </message>
    <message>
        <source>%I: Info hash</source>
        <translation>%I: Інформаційний хеш</translation>
    </message>
    <message>
        <source>Tip: Encapsulate parameter with quotation marks to avoid text being cut off at whitespace (e.g., "%N")</source>
        <translation>Порада: Обгорніть параметр лапками, щоб уникнути розділення тексту пробілами (наприклад, "%N")</translation>
    </message>
    <message>
        <source>The Web UI username must be at least 3 characters long.</source>
        <translation>Ім'я користувача веб-інтерфейсу повинне містити хоча б 3 символи.</translation>
    </message>
    <message>
        <source>The Web UI password must be at least 6 characters long.</source>
        <translation>Пароль від Веб-інтерфейсу повинен містити хоча би 6 символів.</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>хвилин</translation>
    </message>
    <message>
        <source>KiB/s</source>
        <translation>КіБ/с</translation>
    </message>
    <message>
        <source>Enable clickjacking protection</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Enable Cross-Site Request Forgery (CSRF) protection</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Delete .torrent files afterwards</source>
        <translation>Видаляти файли .torrent опісля</translation>
    </message>
    <message>
        <source>Download rate threshold:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Upload rate threshold:</source>
        <translation>Поріг швидкості відвантаження:</translation>
    </message>
    <message>
        <source>Change current password</source>
        <translation>Змінити поточний пароль</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>Автоматичний</translation>
    </message>
    <message>
        <source>Use alternative Web UI</source>
        <translation>Використовувати альтернативний Веб-інтерфейс</translation>
    </message>
    <message>
        <source>Default Save Path:</source>
        <translation>Шлях збереження за замовчуванням:</translation>
    </message>
    <message>
        <source>The alternative Web UI files location cannot be blank.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Do not start the download automatically</source>
        <translation>Не починати завантаження автоматично</translation>
    </message>
    <message>
        <source>Switch torrent to Manual Mode</source>
        <translation>Перемкнути торрент до ручного режиму</translation>
    </message>
    <message>
        <source>When Torrent Category changed:</source>
        <translation>Коли змінилася категорія торренту:</translation>
    </message>
    <message>
        <source>Relocate affected torrents</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Apply rate limit to peers on LAN</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>0 means unlimited</source>
        <translation>0 означає необмежено</translation>
    </message>
    <message>
        <source>Relocate torrent</source>
        <translation>Перемістити торрент</translation>
    </message>
    <message>
        <source>When Default Save Path changed:</source>
        <translation>Коли змінився стандартний шлях збереження:</translation>
    </message>
    <message>
        <source>Enable Host header validation</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Security</source>
        <translation>Безпека</translation>
    </message>
    <message>
        <source>When Category Save Path changed:</source>
        <translation>Коли змінився шлях збереження категорії:</translation>
    </message>
    <message>
        <source>Create subfolder for torrents with multiple files</source>
        <translation>Створити підкаталог для торрентів з декількома файлами</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>секунд</translation>
    </message>
    <message>
        <source>Switch affected torrents to Manual Mode</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Files location:</source>
        <translation>Розташування файлів:</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Вручну</translation>
    </message>
    <message>
        <source>Torrent inactivity timer:</source>
        <translation>Час простоювання торрента:</translation>
    </message>
    <message>
        <source>Default Torrent Management Mode:</source>
        <translation>Режим керування торрентами за замовчуванням:</translation>
    </message>
    <message>
        <source>When adding a torrent</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>PeerListWidget</name>
    <message>
        <source>IP</source>
        <translation>IP</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Порт</translation>
    </message>
    <message>
        <source>Flags</source>
        <translation>Прапори</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>З'єднання</translation>
    </message>
    <message>
        <source>Client</source>
        <comment>i.e.: Client application</comment>
        <translation>Клієнт</translation>
    </message>
    <message>
        <source>Progress</source>
        <comment>i.e: % downloaded</comment>
        <translation>Прогрес</translation>
    </message>
    <message>
        <source>Down Speed</source>
        <comment>i.e: Download speed</comment>
        <translation>Шв. завантаження</translation>
    </message>
    <message>
        <source>Up Speed</source>
        <comment>i.e: Upload speed</comment>
        <translation>Шв. вивантаження</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <comment>i.e: total data downloaded</comment>
        <translation>Завантажено</translation>
    </message>
    <message>
        <source>Uploaded</source>
        <comment>i.e: total data uploaded</comment>
        <translation>Вивантажено</translation>
    </message>
    <message>
        <source>Relevance</source>
        <comment>i.e: How relevant this peer is to us. How many pieces it has that we don't.</comment>
        <translation>Доречність</translation>
    </message>
    <message>
        <source>Files</source>
        <comment>i.e. files that are being downloaded right now</comment>
        <translation>Файли</translation>
    </message>
    <message>
        <source>Country</source>
        <translation>Країна</translation>
    </message>
</context>
<context>
    <name>PropListDelegate</name>
    <message>
        <source>Normal</source>
        <comment>Normal (priority)</comment>
        <translation>Нормальний</translation>
    </message>
    <message>
        <source>High</source>
        <comment>High (priority)</comment>
        <translation>Високий</translation>
    </message>
    <message>
        <source>Maximum</source>
        <comment>Maximum (priority)</comment>
        <translation>Максимальний</translation>
    </message>
</context>
<context>
    <name>PropTabBar</name>
    <message>
        <source>General</source>
        <translation>Загальні</translation>
    </message>
    <message>
        <source>Trackers</source>
        <translation>Трекери</translation>
    </message>
    <message>
        <source>Peers</source>
        <translation>Піри</translation>
    </message>
    <message>
        <source>HTTP Sources</source>
        <translation>Джерела HTTP</translation>
    </message>
    <message>
        <source>Content</source>
        <translation>Вміст</translation>
    </message>
</context>
<context>
    <name>PropertiesWidget</name>
    <message>
        <source>Downloaded:</source>
        <translation>Завантажено:</translation>
    </message>
    <message>
        <source>Transfer</source>
        <translation>Передача</translation>
    </message>
    <message>
        <source>Time Active:</source>
        <extracomment>Time (duration) the torrent is active (not paused)</extracomment>
        <translation>Активний протягом:</translation>
    </message>
    <message>
        <source>ETA:</source>
        <translation>Залишилось:</translation>
    </message>
    <message>
        <source>Uploaded:</source>
        <translation>Вивантажено:</translation>
    </message>
    <message>
        <source>Seeds:</source>
        <translation>Сіди:</translation>
    </message>
    <message>
        <source>Download Speed:</source>
        <translation>Швидкість завантаження:</translation>
    </message>
    <message>
        <source>Upload Speed:</source>
        <translation>Швидкість вивантаження:</translation>
    </message>
    <message>
        <source>Peers:</source>
        <translation>Піри:</translation>
    </message>
    <message>
        <source>Download Limit:</source>
        <translation>Обмеження завантаження:</translation>
    </message>
    <message>
        <source>Upload Limit:</source>
        <translation>Обмеження вивантаження:</translation>
    </message>
    <message>
        <source>Wasted:</source>
        <translation>Змарновано:</translation>
    </message>
    <message>
        <source>Connections:</source>
        <translation>З'єднання:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Інформація</translation>
    </message>
    <message>
        <source>Comment:</source>
        <translation>Коментар:</translation>
    </message>
    <message>
        <source>Share Ratio:</source>
        <translation>Коефіцієнт роздачі:</translation>
    </message>
    <message>
        <source>Reannounce In:</source>
        <translation>Переанонсувати через:</translation>
    </message>
    <message>
        <source>Last Seen Complete:</source>
        <translation>Востаннє завершений:</translation>
    </message>
    <message>
        <source>Total Size:</source>
        <translation>Загальний розмір:</translation>
    </message>
    <message>
        <source>Pieces:</source>
        <translation>Частин:</translation>
    </message>
    <message>
        <source>Created By:</source>
        <translation>Створено:</translation>
    </message>
    <message>
        <source>Added On:</source>
        <translation>Додано:</translation>
    </message>
    <message>
        <source>Completed On:</source>
        <translation>Завершено:</translation>
    </message>
    <message>
        <source>Created On:</source>
        <translation>Створено:</translation>
    </message>
    <message>
        <source>Torrent Hash:</source>
        <translation>Хеш торрента:</translation>
    </message>
    <message>
        <source>Save Path:</source>
        <translation>Шлях збереження:</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>Ніколи</translation>
    </message>
    <message>
        <source>%1 x %2 (have %3)</source>
        <comment>(torrent pieces) eg 152 x 4MB (have 25)</comment>
        <translation>%1 × %2 (є %3)</translation>
    </message>
    <message>
        <source>%1 (%2 this session)</source>
        <translation>%1 (%2 цього сеансу)</translation>
    </message>
    <message>
        <source>%1 (%2 max)</source>
        <comment>%1 and %2 are numbers, e.g. 3 (10 max)</comment>
        <translation>%1 (макс. %2)</translation>
    </message>
    <message>
        <source>%1 (%2 total)</source>
        <comment>%1 and %2 are numbers, e.g. 3 (10 total)</comment>
        <translation>%1 (%2 загалом)</translation>
    </message>
    <message>
        <source>%1 (%2 avg.)</source>
        <comment>%1 and %2 are speed rates, e.g. 200KiB/s (100KiB/s avg.)</comment>
        <translation>%1 (%2 середн.)</translation>
    </message>
    <message>
        <source>Download limit:</source>
        <translation>Обмеження завантаження:</translation>
    </message>
    <message>
        <source>Upload limit:</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>ScanFoldersModel</name>
    <message>
        <source>Monitored Folder</source>
        <translation>Тека стеження</translation>
    </message>
    <message>
        <source>Override Save Location</source>
        <translation>Перевизначити місце збереження</translation>
    </message>
    <message>
        <source>Monitored folder</source>
        <translation>Тека стеження</translation>
    </message>
    <message>
        <source>Default save location</source>
        <translation>Місце збереження за замовчуванням</translation>
    </message>
</context>
<context>
    <name>SpeedLimitDialog</name>
    <message>
        <source>KiB/s</source>
        <translation>КіБ/с</translation>
    </message>
</context>
<context>
    <name>StatsDialog</name>
    <message>
        <source>Statistics</source>
        <translation>Статистика</translation>
    </message>
    <message>
        <source>User statistics</source>
        <translation>Статистика користувача</translation>
    </message>
    <message>
        <source>Cache statistics</source>
        <translation>Статистика кешу</translation>
    </message>
    <message>
        <source>Read cache hits:</source>
        <translation>Попадань в кеші зчитування:</translation>
    </message>
    <message>
        <source>Average time in queue:</source>
        <translation>Середній час в черзі:</translation>
    </message>
    <message>
        <source>Connected peers:</source>
        <translation>Під'єднані піри:</translation>
    </message>
    <message>
        <source>All-time share ratio:</source>
        <translation>Коєфіцієнт відданого за весь час:</translation>
    </message>
    <message>
        <source>All-time download:</source>
        <translation>Завантажено за весь час:</translation>
    </message>
    <message>
        <source>Session waste:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>All-time upload:</source>
        <translation>Відвантажено за весь час:</translation>
    </message>
    <message>
        <source>Total buffer size:</source>
        <translation>Загальний розмір буфера:</translation>
    </message>
    <message>
        <source>Performance statistics</source>
        <translation>Статистика швидкодії</translation>
    </message>
    <message>
        <source>Queued I/O jobs:</source>
        <translation>Завдання вводу/виводу в черзі:</translation>
    </message>
    <message>
        <source>Write cache overload:</source>
        <translation>Перевантаження кешу запису:</translation>
    </message>
    <message>
        <source>Read cache overload:</source>
        <translation>Перевантаження кешу зчитування:</translation>
    </message>
    <message>
        <source>Total queued size:</source>
        <translation>Загальний розмір в черзі:</translation>
    </message>
</context>
<context>
    <name>StatusBar</name>
    <message>
        <source>DHT: %1 nodes</source>
        <translation>DHT: %1 вузлів</translation>
    </message>
</context>
<context>
    <name>StatusFilterWidget</name>
    <message>
        <source>All (0)</source>
        <comment>this is for the status filter</comment>
        <translation>Всі (0)</translation>
    </message>
    <message>
        <source>Downloading (0)</source>
        <translation>Завантажуються (0)</translation>
    </message>
    <message>
        <source>Seeding (0)</source>
        <translation>Роздаються (0)</translation>
    </message>
    <message>
        <source>Completed (0)</source>
        <translation>Завершені (0)</translation>
    </message>
    <message>
        <source>Resumed (0)</source>
        <translation>Відновлені (0)</translation>
    </message>
    <message>
        <source>Paused (0)</source>
        <translation>Призупинені (0)</translation>
    </message>
    <message>
        <source>Active (0)</source>
        <translation>Активні (0)</translation>
    </message>
    <message>
        <source>Inactive (0)</source>
        <translation>Неактивні (0)</translation>
    </message>
    <message>
        <source>Errored (0)</source>
        <translation>З помилкою (0)</translation>
    </message>
    <message>
        <source>All (%1)</source>
        <translation>Всі (%1)</translation>
    </message>
    <message>
        <source>Downloading (%1)</source>
        <translation>Завантажуються (%1)</translation>
    </message>
    <message>
        <source>Seeding (%1)</source>
        <translation>Роздаються (%1)</translation>
    </message>
    <message>
        <source>Completed (%1)</source>
        <translation>Завершені (%1)</translation>
    </message>
    <message>
        <source>Paused (%1)</source>
        <translation>Призупинені (%1)</translation>
    </message>
    <message>
        <source>Resumed (%1)</source>
        <translation>Відновлені (%1)</translation>
    </message>
    <message>
        <source>Active (%1)</source>
        <translation>Активні (%1)</translation>
    </message>
    <message>
        <source>Inactive (%1)</source>
        <translation>Неактивні (%1)</translation>
    </message>
    <message>
        <source>Errored (%1)</source>
        <translation>З помилкою (%1)</translation>
    </message>
</context>
<context>
    <name>TorrentContentModel</name>
    <message>
        <source>Name</source>
        <translation>Назва</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Розмір</translation>
    </message>
    <message>
        <source>Progress</source>
        <translation>Прогрес</translation>
    </message>
    <message>
        <source>Download Priority</source>
        <translation>Пріоритет завантаження</translation>
    </message>
    <message>
        <source>Remaining</source>
        <translation>Залишилось</translation>
    </message>
    <message>
        <source>Availability</source>
        <translation>Доступно</translation>
    </message>
</context>
<context>
    <name>TransferListModel</name>
    <message>
        <source>Name</source>
        <comment>i.e: torrent name</comment>
        <translation>Назва</translation>
    </message>
    <message>
        <source>Size</source>
        <comment>i.e: torrent size</comment>
        <translation>Розмір</translation>
    </message>
    <message>
        <source>Done</source>
        <comment>% Done</comment>
        <translation>Зроблено</translation>
    </message>
    <message>
        <source>Status</source>
        <comment>Torrent status (e.g. downloading, seeding, paused)</comment>
        <translation>Статус</translation>
    </message>
    <message>
        <source>Seeds</source>
        <comment>i.e. full sources (often untranslated)</comment>
        <translation>Сіди</translation>
    </message>
    <message>
        <source>Peers</source>
        <comment>i.e. partial sources (often untranslated)</comment>
        <translation>Піри</translation>
    </message>
    <message>
        <source>Down Speed</source>
        <comment>i.e: Download speed</comment>
        <translation>Шв. завантаження</translation>
    </message>
    <message>
        <source>Up Speed</source>
        <comment>i.e: Upload speed</comment>
        <translation>Шв. вивантаження</translation>
    </message>
    <message>
        <source>Ratio</source>
        <comment>Share ratio</comment>
        <translation>Коефіцієнт</translation>
    </message>
    <message>
        <source>ETA</source>
        <comment>i.e: Estimated Time of Arrival / Time left</comment>
        <translation>Залишилось</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Категорія</translation>
    </message>
    <message>
        <source>Tags</source>
        <translation>Мітки</translation>
    </message>
    <message>
        <source>Added On</source>
        <comment>Torrent was added to transfer list on 01/01/2010 08:00</comment>
        <translation>Додано</translation>
    </message>
    <message>
        <source>Completed On</source>
        <comment>Torrent was completed on 01/01/2010 08:00</comment>
        <translation>Завершено о</translation>
    </message>
    <message>
        <source>Tracker</source>
        <translation>Трекер</translation>
    </message>
    <message>
        <source>Down Limit</source>
        <comment>i.e: Download limit</comment>
        <translation>Ліміт завантаження</translation>
    </message>
    <message>
        <source>Up Limit</source>
        <comment>i.e: Upload limit</comment>
        <translation>Ліміт вивантаження</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <comment>Amount of data downloaded (e.g. in MB)</comment>
        <translation>Завантажено</translation>
    </message>
    <message>
        <source>Uploaded</source>
        <comment>Amount of data uploaded (e.g. in MB)</comment>
        <translation>Вивантажено</translation>
    </message>
    <message>
        <source>Session Download</source>
        <comment>Amount of data downloaded since program open (e.g. in MB)</comment>
        <translation>Завантажено за сеанс</translation>
    </message>
    <message>
        <source>Session Upload</source>
        <comment>Amount of data uploaded since program open (e.g. in MB)</comment>
        <translation>Вивантажено за сеанс</translation>
    </message>
    <message>
        <source>Remaining</source>
        <comment>Amount of data left to download (e.g. in MB)</comment>
        <translation>Залишилось</translation>
    </message>
    <message>
        <source>Time Active</source>
        <comment>Time (duration) the torrent is active (not paused)</comment>
        <translation>Активний протягом</translation>
    </message>
    <message>
        <source>Save path</source>
        <comment>Torrent save path</comment>
        <translation>Шлях збереження</translation>
    </message>
    <message>
        <source>Completed</source>
        <comment>Amount of data completed (e.g. in MB)</comment>
        <translation>Завершено</translation>
    </message>
    <message>
        <source>Ratio Limit</source>
        <comment>Upload share ratio limit</comment>
        <translation>Обмеження коефіцієнта</translation>
    </message>
    <message>
        <source>Last Seen Complete</source>
        <comment>Indicates the time when the torrent was last seen complete/whole</comment>
        <translation>Востаннє завершений</translation>
    </message>
    <message>
        <source>Last Activity</source>
        <comment>Time passed since a chunk was downloaded/uploaded</comment>
        <translation>Востаннє активний</translation>
    </message>
    <message>
        <source>Total Size</source>
        <comment>i.e. Size including unwanted data</comment>
        <translation>Загальний розмір</translation>
    </message>
</context>
<context>
    <name>TrackerListWidget</name>
    <message>
        <source>URL</source>
        <translation>URL</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Статус</translation>
    </message>
    <message>
        <source>Peers</source>
        <translation>Піри</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Повідомлення</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <translation>Завантажено</translation>
    </message>
    <message>
        <source>Tracker URL:</source>
        <translation>URL трекера:</translation>
    </message>
    <message>
        <source>Updating...</source>
        <translation>Оновлюється...</translation>
    </message>
    <message>
        <source>Working</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Disabled</source>
        <translation>Вимкнено</translation>
    </message>
    <message>
        <source>Not contacted yet</source>
        <translation>Ще не зв'язувався</translation>
    </message>
    <message>
        <source>#</source>
        <translation>№</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>—</translation>
    </message>
    <message>
        <source>Seeds</source>
        <translation>Сіди</translation>
    </message>
    <message>
        <source>Not working</source>
        <translation>Не працює</translation>
    </message>
    <message>
        <source>Copy tracker URL</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Add a new tracker...</source>
        <translation>Додати новий трекер...</translation>
    </message>
    <message>
        <source>Edit tracker URL...</source>
        <translation>Редагувати адресу трекера...</translation>
    </message>
    <message>
        <source>Tracker editing</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Leeches</source>
        <translation>Лічери</translation>
    </message>
    <message>
        <source>Remove tracker</source>
        <translation>Вилучити трекер</translation>
    </message>
</context>
<context>
    <name>TrackersAdditionDialog</name>
    <message>
        <source>Trackers addition dialog</source>
        <translation>Додавання трекера</translation>
    </message>
    <message>
        <source>List of trackers to add (one per line):</source>
        <translation>Список трекерів, які ви хочете додати (один на рядок):</translation>
    </message>
</context>
<context>
    <name>TransferListDelegate</name>
    <message>
        <source>%1 ago</source>
        <comment>e.g.: 1h 20m ago</comment>
        <translation>%1 тому</translation>
    </message>
    <message>
        <source>Allocating</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Paused</source>
        <translation>Призупинені</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>Завершені</translation>
    </message>
    <message>
        <source>Moving</source>
        <translation>Переміщення</translation>
    </message>
    <message>
        <source>[F] Seeding</source>
        <translation>[П] Роздається</translation>
    </message>
    <message>
        <source>Seeding</source>
        <translation>Роздаються</translation>
    </message>
    <message>
        <source>Queued</source>
        <translation>В черзі</translation>
    </message>
    <message>
        <source>Errored</source>
        <translation>З помилкою</translation>
    </message>
    <message>
        <source>[F] Downloading</source>
        <translation>[П] Завантажується</translation>
    </message>
    <message>
        <source>Downloading metadata</source>
        <translation>Завантажуються метадані</translation>
    </message>
    <message>
        <source>Checking</source>
        <translation>Перевіряється</translation>
    </message>
    <message>
        <source>Missing Files</source>
        <translation>Відсутні файли</translation>
    </message>
    <message>
        <source>Queued for checking</source>
        <translation>В черзі на перевірку</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation>Завантажується</translation>
    </message>
    <message>
        <source>Checking resume data</source>
        <translation>Перевірка даних відновлення</translation>
    </message>
    <message>
        <source>Stalled</source>
        <translation>Заглох</translation>
    </message>
</context>
<context>
    <name>TransferListFiltersWidget</name>
    <message>
        <source>Status</source>
        <translation>Статус</translation>
    </message>
    <message>
        <source>Categories</source>
        <translation>Категорії</translation>
    </message>
</context>
<context>
    <name>TransferListWidget</name>
    <message>
        <source>Torrent Download Speed Limiting</source>
        <translation>Обмеження швидкості завантаження торрента</translation>
    </message>
    <message>
        <source>Torrent Upload Speed Limiting</source>
        <translation>Обмеження швидкості вивантаження торрента</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Перейменувати</translation>
    </message>
    <message>
        <source>Resume</source>
        <comment>Resume/start the torrent</comment>
        <translation>Продовжити</translation>
    </message>
    <message>
        <source>Force Resume</source>
        <comment>Force Resume/start the torrent</comment>
        <translation>Примусово продовжити</translation>
    </message>
    <message>
        <source>Pause</source>
        <comment>Pause the torrent</comment>
        <translation>Призупинити</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>Delete the torrent</comment>
        <translation>Видалити</translation>
    </message>
    <message>
        <source>Limit share ratio...</source>
        <translation>Обмежити коефіцієнт роздачі...</translation>
    </message>
    <message>
        <source>Limit upload rate...</source>
        <translation>Обмежити швидкість вивантаження...</translation>
    </message>
    <message>
        <source>Limit download rate...</source>
        <translation>Обмежити швидкість завантаження...</translation>
    </message>
    <message>
        <source>Move up</source>
        <comment>i.e. move up in the queue</comment>
        <translation>Посунути вперед</translation>
    </message>
    <message>
        <source>Move down</source>
        <comment>i.e. Move down in the queue</comment>
        <translation>Посунути назад</translation>
    </message>
    <message>
        <source>Move to top</source>
        <comment>i.e. Move to top of the queue</comment>
        <translation>Перемістити на початок</translation>
    </message>
    <message>
        <source>Move to bottom</source>
        <comment>i.e. Move to bottom of the queue</comment>
        <translation>Перемістити в кінець</translation>
    </message>
    <message>
        <source>Set location...</source>
        <translation>Змінити розташування...</translation>
    </message>
    <message>
        <source>Copy name</source>
        <translation>Копіювати назву</translation>
    </message>
    <message>
        <source>Copy hash</source>
        <translation>Скопіювати хеш</translation>
    </message>
    <message>
        <source>Download first and last pieces first</source>
        <translation>Спочатку завантажувати першу і останню частину</translation>
    </message>
    <message>
        <source>Automatic Torrent Management</source>
        <translation>Автоматичне керування торрентами</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Категорія</translation>
    </message>
    <message>
        <source>New...</source>
        <comment>New category...</comment>
        <translation>Нова...</translation>
    </message>
    <message>
        <source>Reset</source>
        <comment>Reset category</comment>
        <translation>Забрати</translation>
    </message>
    <message>
        <source>Priority</source>
        <translation>Пріоритет</translation>
    </message>
    <message>
        <source>Force recheck</source>
        <translation>Примусова перевірка</translation>
    </message>
    <message>
        <source>Copy magnet link</source>
        <translation>Копіювати magnet-посилання</translation>
    </message>
    <message>
        <source>Super seeding mode</source>
        <translation>Режим супер-сідування</translation>
    </message>
    <message>
        <source>Rename...</source>
        <translation>Перейменувати...</translation>
    </message>
    <message>
        <source>Download in sequential order</source>
        <translation>Завантажувати послідовно</translation>
    </message>
    <message>
        <source>Force Recheck</source>
        <translation>Примусова перевірка</translation>
    </message>
    <message>
        <source>New Category</source>
        <translation>Нова категорія</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Розташування</translation>
    </message>
    <message>
        <source>New name</source>
        <translation>Нова назва</translation>
    </message>
    <message>
        <source>Set location</source>
        <translation>Задати розташування</translation>
    </message>
    <message>
        <source>Force reannounce</source>
        <translation>Примусове повторне анонсування</translation>
    </message>
    <message>
        <source>Edit Category</source>
        <translation>Змінити категорію</translation>
    </message>
    <message>
        <source>Save path</source>
        <translation>Шлях збереження</translation>
    </message>
</context>
<context>
    <name>UpDownRatioDialog</name>
    <message>
        <source>Torrent Upload/Download Ratio Limiting</source>
        <translation>Обмеження коефіцієнта вивантаження/завантаження торрента</translation>
    </message>
    <message>
        <source>Use global share limit</source>
        <translation>Використовувати глобальні обмеження</translation>
    </message>
    <message>
        <source>Set no share limit</source>
        <translation>Не використовувати обмеження роздачі</translation>
    </message>
    <message>
        <source>Set share limit to</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>ratio</source>
        <translation>коефіцієнт</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>хвилин</translation>
    </message>
</context>
<context>
    <name>about</name>
    <message>
        <source>An advanced BitTorrent client programmed in C++, based on Qt toolkit and libtorrent-rasterbar.</source>
        <translation>Потужний клієнт BitTorrent, запрограмований на C++, на основі бібліотек Qt та libtorrent-rasterbar.</translation>
    </message>
    <message>
        <source>Home Page:</source>
        <translation>Домашня сторінка:</translation>
    </message>
    <message>
        <source>Forum:</source>
        <translation>Форум:</translation>
    </message>
    <message>
        <source>Bug Tracker:</source>
        <translation>Трекер помилок:</translation>
    </message>
</context>
<context>
    <name>confirmDeletionDlg</name>
    <message>
        <source>Deletion confirmation</source>
        <translation>Підтвердження видалення</translation>
    </message>
    <message>
        <source>Also delete the files on the hard disk</source>
        <translation>Також видалити файли на жорсткому диску</translation>
    </message>
    <message>
        <source>Deletion confirmation - qBittorrent</source>
        <translation>Підтвердження видалення - qBittorrent</translation>
    </message>
</context>
<context>
    <name>downloadFromURL</name>
    <message>
        <source>Download from URLs</source>
        <translation>Завантажити з адрес</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Завантажити</translation>
    </message>
    <message>
        <source>Add Torrent Links</source>
        <translation>Додати посилання на торрент</translation>
    </message>
</context>
<context>
    <name>misc</name>
    <message>
        <source>B</source>
        <comment>bytes</comment>
        <translation>Б</translation>
    </message>
    <message>
        <source>KiB</source>
        <comment>kibibytes (1024 bytes)</comment>
        <translation>КіБ</translation>
    </message>
    <message>
        <source>MiB</source>
        <comment>mebibytes (1024 kibibytes)</comment>
        <translation>МіБ</translation>
    </message>
    <message>
        <source>GiB</source>
        <comment>gibibytes (1024 mibibytes)</comment>
        <translation>ГіБ</translation>
    </message>
    <message>
        <source>TiB</source>
        <comment>tebibytes (1024 gibibytes)</comment>
        <translation>ТіБ</translation>
    </message>
    <message>
        <source>PiB</source>
        <comment>pebibytes (1024 tebibytes)</comment>
        <translation>ПіБ</translation>
    </message>
    <message>
        <source>EiB</source>
        <comment>exbibytes (1024 pebibytes)</comment>
        <translation>ЕіБ</translation>
    </message>
    <message>
        <source>/s</source>
        <comment>per second</comment>
        <translation>/с</translation>
    </message>
    <message>
        <source>%1h %2m</source>
        <comment>e.g: 3hours 5minutes</comment>
        <translation>%1г %2хв</translation>
    </message>
    <message>
        <source>%1d %2h</source>
        <comment>e.g: 2days 10hours</comment>
        <translation>%1д %2г</translation>
    </message>
    <message>
        <source>Unknown</source>
        <comment>Unknown (size)</comment>
        <translation>Невідомо</translation>
    </message>
    <message>
        <source>&lt; 1m</source>
        <comment>&lt; 1 minute</comment>
        <translation>&lt; 1хв</translation>
    </message>
    <message>
        <source>%1m</source>
        <comment>e.g: 10minutes</comment>
        <translation>%1хв</translation>
    </message>
</context>
<context>
    <name>TorrentsController</name>
    <message>
        <source>Save path is empty</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>PluginSourceDlg</name>
    <message>
        <source>Cancel</source>
        <translation>Скасувати</translation>
    </message>
    <message>
        <source>Plugin path:</source>
        <translation>Шлях до додатка:</translation>
    </message>
    <message>
        <source>URL or local directory</source>
        <translation>URL або локальний каталог</translation>
    </message>
    <message>
        <source>Install plugin</source>
        <translation>Встановити додаток</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Гаразд</translation>
    </message>
</context>
<context>
    <name>SearchEngineWidget</name>
    <message>
        <source>Seeds:</source>
        <translation>Сіди:</translation>
    </message>
    <message>
        <source>All plugins</source>
        <translation>Всі додатки</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Розмір:</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Зупинити</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Пошук</translation>
    </message>
    <message>
        <source>Search plugins...</source>
        <translation>Пошукові додатки...</translation>
    </message>
    <message>
        <source>All categories</source>
        <translation>Всі категорії</translation>
    </message>
    <message>
        <source>Search in:</source>
        <translation>Шукати у:</translation>
    </message>
    <message>
        <source>Copy description page URL</source>
        <translation>Скопіювати URL сторінки опису</translation>
    </message>
    <message>
        <source>Go to description page</source>
        <translation>Перейти до сторінки опису</translation>
    </message>
    <message>
        <source>Results (showing</source>
        <translation>Результати (показано</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Завантажити</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Фільтр</translation>
    </message>
    <message>
        <source>Torrent names only</source>
        <translation>Лише назви торрентів</translation>
    </message>
    <message>
        <source>Only enabled</source>
        <translation>Лише увімкнені</translation>
    </message>
    <message>
        <source>out of</source>
        <translation>із</translation>
    </message>
    <message>
        <source>Everywhere</source>
        <translation>Всюди</translation>
    </message>
</context>
<context>
    <name>PluginSelectDlg</name>
    <message>
        <source>Uninstall</source>
        <translation>Видалити</translation>
    </message>
    <message>
        <source>Install new plugin</source>
        <translation>Встановити новий додаток</translation>
    </message>
    <message>
        <source>You can get new search engine plugins here:</source>
        <translation>Тут можна отримати нові плагіни пошукової системи:</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Закрити</translation>
    </message>
    <message>
        <source>Installed search plugins:</source>
        <translation>Встановлені пошукові додатки:</translation>
    </message>
    <message>
        <source>Enabled</source>
        <translation>Увімкнено</translation>
    </message>
    <message>
        <source>Warning: Be sure to comply with your country's copyright laws when downloading torrents from any of these search engines.</source>
        <translation>Попередження: Під час завантаження торрентів з будь-якої з цих пошукових систем, обов'язково дотримуйтесь законів про захист авторських прав у вашій країні.</translation>
    </message>
    <message>
        <source>Check for updates</source>
        <translation>Перевірити оновлення</translation>
    </message>
    <message>
        <source>Search plugins</source>
        <translation>Пошукові додатки</translation>
    </message>
</context>
<context>
    <name>SearchResultsTable</name>
    <message>
        <source>Name</source>
        <translation>Назва</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Розмір</translation>
    </message>
    <message>
        <source>Leechers</source>
        <translation>Лічери</translation>
    </message>
    <message>
        <source>Search engine</source>
        <translation>Пошуковик</translation>
    </message>
    <message>
        <source>Seeders</source>
        <translation>Сідери</translation>
    </message>
</context>
<context>
    <name>SearchPluginsTable</name>
    <message>
        <source>Name</source>
        <translation>Назва</translation>
    </message>
    <message>
        <source>Url</source>
        <translation>URL</translation>
    </message>
    <message>
        <source>Enabled</source>
        <translation>Увімкнено</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Версія</translation>
    </message>
</context>
</TS>